#
# spec file for package createrepo_c
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define major 0
%define libname lib%{name}%{major}
%define devname lib%{name}-devel

%define version_unconverted 0.10.0.git20160503.7c6fae0

Name:           createrepo_c
Summary:        Creates a common metadata repository
License:        GPL-2.0
Group:          System/Packages
Version:        0.10.0.git20160503.7c6fae0
Release:        2.5
Url:            https://github.com/rpm-software-management/createrepo_c
Source0:        %{name}-%{version}.tar.gz

BuildRequires:  bash-completion

%if 0%{?suse_version} >= 1330 
BuildRequires:  bash-completion-devel
%endif

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  file-devel
BuildRequires:  glib2-devel >= 2.22.0
BuildRequires:  libbz2-devel
BuildRequires:  libcurl-devel
BuildRequires:  libexpat-devel
BuildRequires:  libxml2-devel
BuildRequires:  lzma-devel
BuildRequires:  openssl-devel
BuildRequires:  rpm-devel >= 4.9.0
BuildRequires:  sqlite3-devel
BuildRequires:  zlib-devel

Requires:       %{libname} = %{version}-%{release}

# prevent provides from nonstandard paths:
%global __provides_exclude ^(%{python_sitearch}/.*\\.so\\|%{python3_sitearch}/.*\\.so)$

%description
C implementation of Createrepo.
A set of utilities (createrepo_c, mergerepo_c, modifyrepo_c)
for generating a common metadata repository from a directory of
rpm packages and maintaining it.

%package -n %{libname}
Summary:        Library for repodata manipulation
Group:          System/Libraries
# The function to create DeltaRPMs calls /usr/bin/makedeltarpm,
# which is part of the 'deltarpm' package
Requires:       deltarpm

%description -n %{libname}
Libraries for applications using the createrepo_c library
for easy manipulation with a repodata.

%package -n %{devname}
Summary:        Library for repodata manipulation
Group:          Development/Libraries/C and C++
Provides:       %{name}-devel = %{version}-%{release}
Requires:       %{libname} = %{version}-%{release}
Requires:       pkg-config

%description -n %{devname}
This package contains the createrepo_c C library and header files.
These development files are for easy manipulation with a repodata.

%prep
%setup -q

%if %{with python3}
rm -rf py3
mkdir py3
%endif

%build
%cmake -DENABLE_LEGACY_WEAKTAGS=1 -DENABLE_DRPM=OFF -DENABLE_PYTHON=OFF
make %{?_smp_mflags}
make doc-c

%check
pushd ./build
make tests
make ARGS="-V" test
popd

%install
pushd ./build
%make_install
popd

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files
%doc README.md COPYING
%_mandir/man8/createrepo_c.8.*
%_mandir/man8/mergerepo_c.8.*
%_mandir/man8/modifyrepo_c.8.*
%_mandir/man8/sqliterepo_c.8.*
%{_datadir}/bash-completion/completions/
%{_bindir}/createrepo_c
%{_bindir}/mergerepo_c
%{_bindir}/modifyrepo_c
%{_bindir}/sqliterepo_c

%files -n %{libname}
%doc COPYING
%{_libdir}/libcreaterepo_c.so.%{major}
%{_libdir}/libcreaterepo_c.so.%{major}.*

%files -n %{devname}
%{_libdir}/libcreaterepo_c.so
%{_libdir}/pkgconfig/createrepo_c.pc
%{_includedir}/createrepo_c/
%doc build/doc/html COPYING

%changelog
* Mon Feb  1 2016 ngompa13@gmail.com
- Disable Python 3 bindings for SLE
* Mon Feb  1 2016 ngompa13@gmail.com
- Update to 0.10.0, add Python 3 bindings
* Thu Oct 29 2015 ngompa13@gmail.com
- Initial package based on Mageia package
